@@ -33,18 +33,22 @@ class LvsClient(BaseClient):
         if 'alert' in r.text:
             error = re.findall("alert\('(.*)'\)", r.text)[0]
             raise exceptions.AuthenticationError(error)
+        print(r.text)
+        print(r.url)
         self.is_authenticated = True
 
     @staticmethod
     def get_name_rank(html):
         soup = BeautifulSoup(html, 'html.parser')
         info = soup.find(attrs={'id': 'login-info'}).find_all('span')
-        return [i.text.lower().split('sub')[0] for i in info]
+        info2 = soup.find(attrs={'class': 'rep navlink'})
+        return info2.text.lower(), ''
+        # return [i.text.lower().split('sub')[0] for i in info]
 
     @cached_property
     @login_required
     def profile(self):
-        r = self.get(self._url())
+        r = self.get(self._url('report/info'))
         return self.get_name_rank(r.text)
 
     @property
